// SPDX-FileCopyrightText: Copyright (c) Kitware Inc.
// SPDX-License-Identifier: BSD-3-Clause
#ifndef vtkCPPythonScriptPipelineConfig_h
#define vtkCPPythonScriptPipelineConfig_h

// These variables are used to locate the python module files since we cannot
// reply on the executable path to locate python module files.
#define PARAVIEW_BINARY_DIR "C:/W/B/src/build-CLANGARM64"
#define PARAVIEW_INSTALL_DIR "/clangarm64"

#endif
